@@ -51,7 +51,6 @@ namespace gbrainy.Clients.Classical.Dialogs
 			minplayedspinbutton.Value = Preferences.Get <int> (Preferences.MinPlayedGamesKey);
 			colorblindcheckbutton.Active = Preferences.Get <bool> (Preferences.ColorBlindKey);
 			englishcheckbutton.Active = Preferences.Get <bool> (Preferences.EnglishKey);
-			loadextensionscheckbutton.Active = Preferences.Get <bool> (Preferences.LoadPlugginsKey);
 			usesoundscheckbutton.Active = Preferences.Get <bool> (Preferences.SoundsKey);
 
 			switch ((GameDifficulty) Preferences.Get <int> (Preferences.DifficultyKey)) {
@@ -89,10 +88,6 @@ namespace gbrainy.Clients.Classical.Dialogs
 				}
 				more = store.IterNext (ref iter);
 			}
-
-			#if !MONO_ADDINS
-				loadextensionscheckbutton.Visible = false;
-			#endif
 		}
 
 		private GameDifficulty Difficulty {
@@ -132,7 +127,6 @@ namespace gbrainy.Clients.Classical.Dialogs
 			Preferences.Set <int>  (Preferences.MinPlayedGamesKey, (int) minplayedspinbutton.Value);
 			Preferences.Set <bool> (Preferences.ColorBlindKey, colorblindcheckbutton.Active);
 			Preferences.Set <bool> (Preferences.EnglishKey, englishcheckbutton.Active);
-			Preferences.Set <bool> (Preferences.LoadPlugginsKey, loadextensionscheckbutton.Active);
 			Preferences.Set <bool> (Preferences.SoundsKey, usesoundscheckbutton.Active);
 
 			TreeIter iter;
