@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 using System;
@@ -42,11 +40,11 @@ namespace gbrainy.Games.Logic
 		}
 
 		public override string Name {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Divide circles");}
+			get {return Translations.GetString ("Divide circles");}
 		}
 
 		public override string Question {
-			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("In the last figure, in how many regions is the circle divided into when all dots are connected?");} 
+			get {return Translations.GetString ("In the last figure, in how many regions is the circle divided into when all dots are connected?");} 
 		}
 
 		protected override void Initialize ()
@@ -109,14 +107,13 @@ namespace gbrainy.Games.Logic
 					new Circle (0.14, 0.29),
 				}, true);
 
-			gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
-			gr.ShowPangoText (HasNRegionString (2));
+			gr.DrawTextCentered (pos_x + figure_size, pos_y + figure_size * 2 + 0.07, HasNRegionString (2));
 			gr.Stroke ();
 
 			// Second circle
 			pos_x += 0.4;
 			gr.Arc (pos_x + figure_size, pos_y + figure_size, figure_size, 0, 2 * Math.PI);
-			gr.Stroke ();		
+			gr.Stroke ();
 			DrawAndConnectPoints (gr, pos_x, pos_y,
 				new Circle [] {
 					new Circle (0.01, 0.06),
@@ -124,8 +121,7 @@ namespace gbrainy.Games.Logic
 					new Circle (0.14, 0.29),
 				}, true);
 
-			gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
-			gr.ShowPangoText (HasNRegionString (4));
+			gr.DrawTextCentered (pos_x + figure_size, pos_y + figure_size * 2 + 0.07, HasNRegionString (4));
 			gr.Stroke ();
 
 			// Third circle
@@ -141,8 +137,7 @@ namespace gbrainy.Games.Logic
 					new Circle (0.27, 0.21),
 				}, true);
 
-			gr.MoveTo (pos_x, pos_y + figure_size * 2 + 0.05);
-			gr.ShowPangoText (HasNRegionString (8));
+			gr.DrawTextCentered (pos_x + figure_size, pos_y + figure_size * 2 + 0.07, HasNRegionString (8));
 			gr.Stroke ();
 
 			switch (dots) {
@@ -174,9 +169,9 @@ namespace gbrainy.Games.Logic
 			DrawAndConnectPoints (gr, pos_x, pos_y, circles, Answer.Draw);
 		}
 		
-		static string HasNRegionString (int regions)
+		string HasNRegionString (int regions)
 		{
-			return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetPluralString ("Has {0} region", 
+			return String.Format (Translations.GetPluralString ("Has {0} region", 
 				"Has {0} regions", regions), regions);
 			
 		}
